@@ -132,8 +132,7 @@ class CreateRecTaskRequest(AbstractModel):
         :param EngineModelType: 引擎模型类型。
 电话场景：
 • 8k_en：电话 8k 英语；
-• 8k_zh：电话 8k 中文普通话通用（可用于双声道音频）；
-• 8k_zh_s：电话 8k 中文普通话话者分离（仅适用于单声道音频）；
+• 8k_zh：电话 8k 中文普通话通用；
 非电话场景：
 • 16k_zh：16k 中文普通话通用；
 • 16k_zh_video：16k 音视频领域；
@@ -144,7 +143,7 @@ class CreateRecTaskRequest(AbstractModel):
         :type EngineModelType: str
         :param ChannelNum: 语音声道数。1：单声道；2：双声道（仅支持 8k_zh 引擎模型）。
         :type ChannelNum: int
-        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，词时间戳列表，一般用于生成字幕场景)；2：词级别粒度的详细识别结果（包含标点）
+        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，含语速值)；2：词级别粒度的详细识别结果（包含标点）
         :type ResTextFormat: int
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
@@ -1027,7 +1026,7 @@ class SetVocabStateResponse(AbstractModel):
 
 
 class Task(AbstractModel):
-    """录音文件识别请求的返回数据
+    """录音文件识别、实时语音异步识别请求的返回数据
 
     """
 
